Enum android_activity::InputStatus
source · pub enum InputStatus {
Handled,
Unhandled,
}Expand description
Indicates whether an application has handled or ignored an event
If an event is not handled by an application then some default handling may happen.
Variants