KeyboardType

Enum KeyboardType 

#[non_exhaustive]
pub enum KeyboardType { Numeric, Predictive, Alpha, Full, SpecialFunction, }
An enum representing the types of keyboards that may generate key events

See getKeyboardType() docs

Android Extensible Enum

This is a runtime extensible enum and should be handled similar to a #[non_exhaustive] enum to maintain forwards compatibility.

This implements Into<u32> and From<u32> for converting to/from Android SDK integer values.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Numeric

A numeric (12-key) keyboard.

A numeric keyboard supports text entry using a multi-tap approach. It may be necessary to tap a key multiple times to generate the desired letter or symbol.

This type of keyboard is generally designed for thumb typing.



Predictive

A keyboard with all the letters, but with more than one letter per key.

This type of keyboard is generally designed for thumb typing.



Alpha

A keyboard with all the letters, and maybe some numbers.

An alphabetic keyboard supports text entry directly but may have a condensed layout with a small form factor. In contrast to a full keyboard, some symbols may only be accessible using special on-screen character pickers. In addition, to improve typing speed and accuracy, the framework provides special affordances for alphabetic keyboards such as auto-capitalization and toggled / locked shift and alt keys.

This type of keyboard is generally designed for thumb typing.



Full

A full PC-style keyboard.

A full keyboard behaves like a PC keyboard. All symbols are accessed directly by pressing keys on the keyboard without on-screen support or affordances such as auto-capitalization.

This type of keyboard is generally designed for full two hand typing.



SpecialFunction

A keyboard that is only used to control special functions rather than for typing.

A special function keyboard consists only of non-printing keys such as HOME and POWER that are not actually used for typing.