Struct android_activity::input::Pointer
source · pub struct Pointer<'a> { /* private fields */ }Expand description
A view into the data of a specific pointer in a motion event.
pub struct Pointer<'a> { /* private fields */ }A view into the data of a specific pointer in a motion event.