Struct android_activity::AndroidAppWaker
source · pub struct AndroidAppWaker { /* private fields */ }Expand description
A means to wake up the main thread while it is blocked waiting for I/O
Implementations
sourceimpl AndroidAppWaker
impl AndroidAppWaker
sourcepub fn wake(&self)
pub fn wake(&self)
Interrupts the main thread if it is blocked within AndroidApp::poll_events()
If AndroidApp::poll_events() is interrupted it will invoke the poll
callback with a PollEvent::Wake event.