Module input

Module input 

Structs

ButtonState
A bitfield representing the state of buttons during a motion event.
EdgeFlags
A bitfield representing which edges were touched by a motion event.
HistoricalPointer
HistoricalPointerImpl
A view into a pointer at a historical moment
ImeOptions
Flags for [AndroidApp::set_ime_editor_info] as per the android.view.inputmethod.EditorInfo Java API
InputIterator
An exclusive, lending iterator for input events
InputType
Flags specifying the content type of text being input.
KeyCharacterMap
Describes the keys provided by a keyboard device and their associated labels.
KeyEvent
A key event
KeyEventFlags
Flags associated with KeyEvent.
MetaState
A bitfield representing the state of modifier keys during an event.
MotionEvent
A motion event
MotionEventFlags
Flags associated with this MotionEvent.
Pointer
A view into the data of a specific pointer in a motion event.
PointerHistoryIter
An iterator over the historical data of a pointer in a MotionEvent.
PointerHistoryIterImpl
An iterator over the historical points of a specific pointer in a MotionEvent.
PointersIter
An iterator over the pointers in a MotionEvent.
TextInputState
TextSpan
This struct holds a span within a region of text from start to end.

Enums

Axis
An axis of a motion event.
Button
Identifies buttons that are associated with motion events.
InputEvent
Enum of possible input events
InputTypeClass
KeyAction
Key actions.
KeyMapChar
Either represents, a unicode character or combining accent from a KeyCharacterMap, or None for non-printable keys.
KeyboardType
An enum representing the types of keyboards that may generate key events
Keycode
Key codes.
MotionAction
A motion action.
An enum representing the source of an MotionEvent or KeyEvent
TextInputAction
ToolType
The tool type of a pointer.