#[non_exhaustive]pub enum InputTypeClass {
Null = 0,
Text = 1,
Number = 2,
Phone = 3,
DateTime = 4,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Null = 0
Special content type for when no explicit type has been specified.
This should be interpreted to mean that the target input connection is not rich, it can not process and show things like candidate text nor retrieve the current text, so the input method will need to run in a limited “generate key events” mode, if it supports it.
Note that some input methods may not support it, for example a voice-based input method will likely not be able to generate key events even if this flag is set.
Text = 1
Class for normal text.
This class supports the following flags (only one of which should be set):
- TYPE_TEXT_FLAG_CAP_CHARACTERS
- TYPE_TEXT_FLAG_CAP_WORDS
- TYPE_TEXT_FLAG_CAP_SENTENCES.
It also supports the following variations:
- TYPE_TEXT_VARIATION_NORMAL
- TYPE_TEXT_VARIATION_URI
If you do not recognize the variation, normal should be assumed.
Number = 2
Class for numeric text.
This class supports the following flags:
TYPE_NUMBER_FLAG_SIGNEDTYPE_NUMBER_FLAG_DECIMAL
It also supports the following variations:
TYPE_NUMBER_VARIATION_NORMALTYPE_NUMBER_VARIATION_PASSWORD
IME authors: If you do not recognize the variation, normal should be assumed.
Phone = 3
Class for a phone number.
This class currently supports no variations or flags.
DateTime = 4
Class for dates and times.
It supports the following variations:
- TYPE_DATETIME_VARIATION_NORMAL
- TYPE_DATETIME_VARIATION_DATE
- TYPE_DATETIME_VARIATION_TIME