Enum android_activity::input::KeyboardType
source · pub enum KeyboardType {
Numeric,
Predictive,
Alpha,
Full,
SpecialFunction,
Unknown(i32),
}Variants
Numeric
A numeric (12-key) keyboard.
A numeric keyboard supports text entry using a multi-tap approach. It may be necessary to tap a key multiple times to generate the desired letter or symbol.
This type of keyboard is generally designed for thumb typing.
Predictive
A keyboard with all the letters, but with more than one letter per key.
This type of keyboard is generally designed for thumb typing.
Alpha
A keyboard with all the letters, and maybe some numbers.
An alphabetic keyboard supports text entry directly but may have a condensed layout with a small form factor. In contrast to a full keyboard, some symbols may only be accessible using special on-screen character pickers. In addition, to improve typing speed and accuracy, the framework provides special affordances for alphabetic keyboards such as auto-capitalization and toggled / locked shift and alt keys.
This type of keyboard is generally designed for thumb typing.
Full
A full PC-style keyboard.
A full keyboard behaves like a PC keyboard. All symbols are accessed directly by pressing keys on the keyboard without on-screen support or affordances such as auto-capitalization.
This type of keyboard is generally designed for full two hand typing.
SpecialFunction
A keyboard that is only used to control special functions rather than for typing.
A special function keyboard consists only of non-printing keys such as HOME and POWER that are not actually used for typing.
Unknown(i32)
An unknown type of keyboard