Enum android_activity::input::Source
source · #[repr(u32)]
pub enum Source {
Show 16 variants
BluetoothStylus,
Dpad,
Gamepad,
Hdmi,
Joystick,
Keyboard,
Mouse,
MouseRelative,
RotaryEncoder,
Sensor,
Stylus,
Touchpad,
Touchscreen,
TouchNavigation,
Trackball,
Unknown,
}Expand description
An enum representing the source of an MotionEvent or KeyEvent
Variants
BluetoothStylus
Dpad
Gamepad
Either a gamepad or a joystick
Hdmi
Joystick
Either a gamepad or a joystick
Keyboard
Pretty much any device with buttons. Query the keyboard type to determine if it has alphabetic keys and can be used for text entry.
Mouse
A pointing device, such as a mouse or trackpad
MouseRelative
A pointing device, such as a mouse or trackpad whose relative motions should be treated as navigation events
RotaryEncoder
An input device akin to a scroll wheel
Sensor
Stylus
Touchpad
Touchscreen
Trackball
Unknown