Enum android_activity::input::ToolType
source · #[repr(u32)]pub enum ToolType {
Unknown,
Finger,
Stylus,
Mouse,
Eraser,
Palm,
}Expand description
The tool type of a pointer.
See the NDK docs
Variants
Unknown
Unknown tool type.
This constant is used when the tool type is not known or is not relevant, such as for a trackball or other non-pointing device.
Finger
The tool is a finger.
Stylus
The tool is a stylus.
Mouse
The tool is a mouse.
Eraser
The tool is an eraser or a stylus being used in an inverted posture.
Palm
The tool is a palm and should be rejected