pub struct ImeOptions(/* private fields */);Expand description
Flags for [AndroidApp::set_ime_editor_info]
as per the android.view.inputmethod.EditorInfo Java API
Implementations
Sourceimpl ImeOptions
impl ImeOptions
Sourcepub const IME_MASK_ACTION: Self
pub const IME_MASK_ACTION: Self
The mask of bits that configure alternative actions for the “enter” key. This helps the IME provide clear feedback for what the key will do and provide alternative mechanisms for taking the same action.
Sourcepub const IME_FLAG_FORCE_ASCII: Self
pub const IME_FLAG_FORCE_ASCII: Self
Indicates that ascii input is a priority (such as for entering an account ID)
Sourcepub const IME_FLAG_NAVIGATE_NEXT: Self
pub const IME_FLAG_NAVIGATE_NEXT: Self
Indicates that it’s possible to navigate focus forwards to something.
This is similar to using IME_ACTION_NEXT except it allows for multi-line input with
an enter key in addition to forward navigation for focus.
This may not be supported by all IMEs (especially on small screens)
Sourcepub const IME_FLAG_NAVIGATE_PREVIOUS: Self
pub const IME_FLAG_NAVIGATE_PREVIOUS: Self
Similar to IME_FLAG_NAVIGATE_NEXT, except it indicates that it’s possible to navigate
focus backwards to something.
Sourcepub const IME_FLAG_NO_ACCESSORY_ACTION: Self
pub const IME_FLAG_NO_ACCESSORY_ACTION: Self
This requests that the IME should not show any accessory actions next to the extracted text UI, when it is in fullscreen mode.
The implication is that you think it’s more important to prioritize having room for previewing more text, instead of showing accessory actions.
Note: In some cases this can make the action unavailable.
Sourcepub const IME_FLAG_NO_ENTER_ACTION: Self
pub const IME_FLAG_NO_ENTER_ACTION: Self
If this flag is not set, IMEs will normally replace the “enter” key with the action supplied. This flag indicates that the action should not be available in-line as a replacement for the “enter” key. Typically this is because the action has such a significant impact or is not recoverable enough that accidentally hitting it should be avoided, such as sending a message.
Sourcepub const IMG_FLAG_NO_EXTRACT_UI: Self
pub const IMG_FLAG_NO_EXTRACT_UI: Self
Don’t show any “extracted-text UI” as part of the on-screen IME.
Some keyboards may show an additional text box above the keyboard for previewing what you type (referred to as the extracted text UI) and it can sometimes be quite large.
The exact semantics of this flag can be unclear sometimes and the UI that becomes visible may not respond to input as you would expect.
This flag may be deprecated in the future and it’s recommend to use
IME_FLAG_NO_FULLSCREEN instead, to avoid having the extracted text UI appear to cover
the full screen.
Sourcepub const IME_FLAG_NO_FULLSCREEN: Self
pub const IME_FLAG_NO_FULLSCREEN: Self
Request that the IME should avoid ever entering a fullscreen mode and should always leave some room for the application UI.
Note: It’s not guaranteed that an IME will honor this state
Sourcepub const IME_FLAG_NO_PERSONALIZED_LEARNING: Self
pub const IME_FLAG_NO_PERSONALIZED_LEARNING: Self
Request that the IME should not update personalized data, such as typing history.
Note: It’s not guaranteed that an IME will honor this state
Sourceimpl ImeOptions
impl ImeOptions
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ImeOptions
impl ImeOptions
Sourcepub const fn iter(&self) -> Iter<ImeOptions>
pub const fn iter(&self) -> Iter<ImeOptions>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ImeOptions>
pub const fn iter_names(&self) -> IterNames<ImeOptions>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ImeOptions
impl ImeOptions
Sourcepub fn set_action(&mut self, action: TextInputAction)
pub fn set_action(&mut self, action: TextInputAction)
Specify what action the IME’s “enter” key should perform.
This helps the IME provide clear feedback for what the key will do and provide alternative mechanisms for taking the same action.
Sourcepub fn action(&self) -> TextInputAction
pub fn action(&self) -> TextInputAction
Get the current action of the IME’s “enter” key.